Coverage for src/httpx/__init__.py: 100%

1 from ._client import * # Client, open_client

2 from ._content import * # Content, File, Files, Form, HTML, JSON, MultiPart, Text

3 from ._headers import * # Headers

4 from ._network import * # NetworkBackend, NetworkStream, timeout

5 from ._pool import * # Connection, ConnectionPool, Transport, open_connection_pool, open_connection

6 from ._response import * # Response

7 from ._request import * # Request

8 from ._streams import * # ByteStream, IterByteStream, FileStream, Stream

9 from ._server import * # serve_http, serve_tcp

10 from ._urlencode import * # quote, unquote, urldecode, urlencode

11 from ._urls import * # QueryParams, URL

12

13

14 __all__ = [

15 "ByteStream",

16 "Client",

17 "Connection",

18 "ConnectionPool",

19 "Content",

20 "File",

21 "FileStream",

22 "Files",

23 "Form",

24 "Headers",

25 "HTML",

26 "IterByteStream",

27 "JSON",

28 "MultiPart",

29 "NetworkBackend",

30 "NetworkStream",

31 "open_client",

32 "open_connection_pool",

33 "open_connection",

34 "Response",

35 "Request",

36 "serve_http",

37 "serve_tcp",

38 "Stream",

39 "Text",

40 "timeout",

41 "Transport",

42 "QueryParams",

43 "quote",

44 "unquote",

45 "URL",

46 "urldecode",

47 "urlencode",

48]

49

50

51 __locals = locals()

52 for __name in __all__:

53 setattr(__locals[__name], "__module__", "httpx")